@@ -200,8 +200,16 @@ twitterDateToPOSIX <- function(dateStr) {
   ## spit dates back at us.  First, let's take a look at unix
   ## epoch time, and then try a few data string formats
   dateInt <- suppressWarnings(as.numeric(dateStr))
+
+  ## Locale must be set to something american-y in order to properly
+  ## parse the Twitter dates. Get the current LC_TIME, reset it on
+  ## exit and then change the locale
+  curLocale <- Sys.getlocale("LC_TIME")
+  on.exit(Sys.setlocale("LC_TIME", curLocale), add=TRUE)
+  Sys.setlocale("LC_TIME", "C")
+  
   if (!is.na(dateInt)) {
-    posDate <- as.POSIXct(dateInt, origin='1970-01-01')
+    posDate <- as.POSIXct(dateInt, tz='UTC', origin='1970-01-01')
   } else {
     posDate <- as.POSIXct(dateStr, tz='UTC',
                           format="%a %b %d %H:%M:%S +0000 %Y")
